@@ -1,7 +1,8 @@
 from .exceptions import *
-from .types import *
+from .models import *
+from .bucket import Client
 
 __title__ = 'aiob2'
 __author__ = 'Dan'
 __license__ = 'MIT'
-__version__ = '0.2.1'
+__version__ = '0.4.1'
